@@ -23,7 +23,7 @@ from jsonutils.functions.parsers import (
     url_validator,
 )
 from jsonutils.query import ParentList, QuerySet
-from jsonutils.utils.dict import UUIDdict
+from jsonutils.utils.dict import UUIDdict, ValuesDict
 from jsonutils.utils.retry import retry_function
 
 
@@ -208,6 +208,24 @@ class JSONNode:
             parent = parent.parent
         return last
 
+    def values(self, *keys, search_upwards=True):
+        output_dict = ValuesDict({k: None for k in keys})
+
+        for key in keys:
+            obj = self
+            while True:
+                if isinstance(obj, JSONDict):
+                    if key in obj:
+                        output_dict[key] = obj[key]._data
+                        break
+                if search_upwards:
+                    obj = obj.parent
+                    if obj is None:
+                        break
+                else:
+                    break
+        return output_dict
+
     def __str__(self):
         return self.json_encode(indent=4)
 
@@ -335,7 +353,14 @@ class JSONCompose(JSONNode):
                 child.parent = self
                 self.__setitem__(index, child)
 
-    def query(self, recursive_=None, include_parent_=None, stop_at_match_=None, **q):
+    def query(
+        self,
+        recursive_=None,
+        include_parent_=None,
+        stop_at_match_=None,
+        native_types_=None,
+        **q,
+    ):
         if not isinstance(stop_at_match_, (int, type(None))):
             raise TypeError(
                 f"Argument stop_at_match_ must be an integer or NoneType, not {type(stop_at_match_)}"
@@ -348,8 +373,12 @@ class JSONCompose(JSONNode):
             recursive_ = config.recursive_queries
         if include_parent_ is None:
             include_parent_ = config.include_parents
+        if native_types_ is None:
+            native_types_ = config.native_types
         # ------------------------
         queryset = QuerySet()
+        if native_types_:
+            queryset._native_types = True
         queryset._root = self  # the node which sends the query
         children = self._child_objects.values()
         for child in children:
@@ -366,6 +395,7 @@ class JSONCompose(JSONNode):
                     recursive_=recursive_,
                     include_parent_=include_parent_,
                     stop_at_match_=stop_at_match_,
+                    native_types_=native_types_,
                     **q,
                 )
         return queryset
@@ -393,6 +423,7 @@ class JSONCompose(JSONNode):
             recursive_=recursive_,
             include_parent_=include_parent_,
             stop_at_match_=2,
+            native_types_=native_types_,
             **q,
         )
 
@@ -400,18 +431,14 @@ class JSONCompose(JSONNode):
             if throw_exceptions_:
                 raise JSONQueryException("The query has not returned any result")
             else:
-                return
+                return None if native_types_ else JSONNull(None)
         elif query.count() > 1:
             if throw_exceptions_:
                 raise JSONQueryMultipleValues("More than one value returned by query")
             else:
                 return query.first()
         else:
-            result = query.first(native_types_=False)
-            if native_types_:
-                return result._data
-            else:
-                return result
+            return query.first()
 
     def annotate(self, **kwargs):
         """
@@ -523,6 +550,8 @@ class JSONDict(dict, JSONCompose):
 
     _DEFAULT = object()
     get = JSONCompose.get  # override get method
+    _get = dict.get  # original get method
+    values = JSONNode.values
 
     def __init__(self, *args, **kwargs):
 
